### <a name="manual"></a> TodoItem block

Allows to render todo item.


| Key       |      Description      | Default |
|:----------|:--------------------- |:-------------- |
| type      |  todoitem                |  
| title      |  title of todo item                |  
| status      |  possible values:<br/>- Open<br/>- Done<br/>- InProgress              |  Open |
| width     |  (optional) width of todo item in cm        | width of current




Example:
```YAML
- type        : todoitem
  title       : 'Do something'
  status      : Open

```

Back to [Documentation](../../../README.md#block_data)
